<?php
/**
 * Template Name: Landing Page
 *
 * Template for the landing page (= "home page", "start page"). WordPress
 * identifies this file by its "Template Name", which can be whatever you want.
 * After creating a page in the WordPress admin area, you can select this
 * template from a list of templates by its name.
 */

get_header();
?>
<main class="landing">
    <header>
        <h1><?php bloginfo('name');?></h1>
        <h2><?php bloginfo('description');?></h2>
    </header>
    <section class="ticker">
        <?php echo apply_filters('the_content', $post->post_content); ?>
    </section>
    <section class="news">
        <?php $recent_posts = wp_get_recent_posts(array('numberposts'=>4)); ?>

        <article>
            <header>
                <h3><a href="<?php echo get_permalink($recent_posts[0]["ID"]); ?>"><?php echo $recent_posts[0]["post_title"]; ?></a></h3>
            </header>
            <div class="content">
                <?php
                    if ( !post_password_required($recent_posts[0]["ID"]) ) {
                        echo substr(wp_strip_all_tags($recent_posts[0]["post_content"]), 0, 250).'...';
                    } else {
                        if (get_bloginfo('language') === 'de-DE') {
                            echo "<p>Den Inhalt des Posts k&ouml;nnt ihr euch nach Eingabe des Passworts durchlesen :)</p>";
                        } else {
                            echo "<p>You can only see the content of this post after entering your password. :)</p>";
                        }
                    }
                ?>
            </div>
        </article>

        <aside>
            <ul>
                <?php for ($i = 1; $i < 4; $i++): ?>
                    <li><a href="<?php echo get_permalink($recent_posts[$i]["ID"])?>" class="headinglike"><?php echo $recent_posts[$i]["post_title"]?></a></li>
                <?php endfor; ?>

            </ul>
            <div class="more">
                <a href="<?php echo home_url()."/blog/"; ?>"><?php
                    if (get_bloginfo('language') === 'de-DE') {
                        echo "Ältere Posts...";
                    } else {
                        echo "older posts...";
                    }
                ?></a>
            </div>
        </aside>
    </section>
    <section class="varia">
        <ul class="seamless box-links">
            <?php if (get_bloginfo('language') === 'de-DE'): ?>
                <li>Im nur für Studierende zugänglichen <a href="http://fs-co.li/wiki">Wiki</a> findet ihr Protokolle, Infos und vieles mehr.</li>
                <li>Wenn ihr Fragen habt, könnt ihr uns auch einfach eine <a href="mailto:fs-coli@cl.uni-heidelberg.de">Mail</a> schreiben.</li>
            <?php else: ?>
                <li>You can find protocols, info and more in the <a href="http://fs-co.li/wiki">Wiki</a>, which is only accessible for students.</li>
                <li>If you have any questions, you can send us an <a href="mailto:fs-coli@cl.uni-heidelberg.de">email</a>.</li>
            <?php endif; ?>
        </ul>

        <p>
            <?php if (get_bloginfo('language') === 'de-DE'): ?>
                Ansonsten könnt ihr auch Post in den FS-Briefkasten werfen oder uns einfach irgendwo auf dem Campus abfangen. Es gibt kein Entkommen!
            <?php else: ?>
                You can also just contact us via our real-life mailbox in the ICL or approach us on campus. There is no escape!
            <?php endif; ?>
        </p>
    </section>
</main>
<?php get_footer();?>
